****************************
The sherpa.astro.plot module
****************************

.. currentmodule:: sherpa.astro.plot

.. automodule:: sherpa.astro.plot

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      ChisqrPlot
      BkgChisqrPlot
      DataPlot
      BkgDataPlot
      DelchiPlot
      BkgDelchiPlot
      FitPlot
      BkgFitPlot
      HistogramPlot
      ARFPlot
      ModelPHAHistogram
      ModelHistogram
      BkgModelPHAHistogram
      BkgModelHistogram
      OrderPlot
      SourcePlot
      BkgSourcePlot
      ModelPlot
      RatioPlot
      BkgRatioPlot
      ResidPlot
      BkgResidPlot

Class Inheritance Diagram
=========================

.. inheritance-diagram::  ChisqrPlot BkgChisqrPlot DataPlot BkgDataPlot DelchiPlot BkgDelchiPlot FitPlot BkgFitPlot HistogramPlot ARFPlot ModelPHAHistogram ModelHistogram BkgModelPHAHistogram BkgModelHistogram OrderPlot SourcePlot BkgSourcePlot ModelPlot RatioPlot BkgRatioPlot ResidPlot BkgResidPlot
   :parts: 1
